package nl.amis.ejb30.hrm;

import java.util.List;

import javax.persistence.EntityTransaction;
import javax.persistence.Query;

public class HrmClient {
    public static void main(String[] args) {
       HrmService hrmService = new HrmService();

       // use the predefined service method for finding all employees
       // and printing all their names
       List<Employee>  emps = hrmService.findAllEmp();
       for (Employee e : emps) { System.out.println(e.getEname()); }
              
       // inside a transaction, create a new department - and persist it!       
       EntityTransaction tx = hrmService.getEntityManager().getTransaction();
       tx.begin();
       // Create a new customer and persist it.
       hrmService.createDept(new Long(50),"New Dept", "Nieuwegein");
       // Commit the transaction
       tx.commit();

       // run an EJBQL query selecting a Department by some Search Criterium
       String ejbql = "SELECT d FROM Department d WHERE d.location = :location";  // you can tell this is an EJBQL query 
       // because of the select d from department d - the whole record is selected, instead of individual columns 
       // and it is selected from the Class-name Department , not the Table-name DEPT!
       Query query = hrmService.getEntityManager().createQuery(ejbql);
       query.setParameter("location", "Nieuwegein");
       List<Department> result = query.getResultList();
       // use a little Java 5.0 Autoboxing for simple, elegant for-looping
       for( Department d:result) {
           System.out.println("Department "+d.getDeptno()+"  "+d.getDname());
       }
       // Close this HrmService instance (and implicitly the EntityManager)
       hrmService.shutdown();
    }
}
