package nl.amis.ejb30.hrm;

import java.sql.Timestamp;

import java.util.List;
import java.util.ListIterator;

import javax.persistence.Query;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.Persistence;

public class HrmService {
    public HrmService() {
        
	EntityManagerFactory emf = Persistence.createEntityManagerFactory("pu1");
	// create EntityManager
	EntityManager em = emf.createEntityManager();
	this.setEntityManager(em);
    }
    
    private EntityManager _entityManager;

    public EntityManager getEntityManager() {
	return _entityManager;
    }

    public void setEntityManager(EntityManager entityManager) {
	_entityManager = entityManager;
    }

    public List<Department> findAllDept() {
	return getEntityManager().createQuery("select object(o) from Department o").getResultList();
    }

    public Department createDept(Long deptno, String dname,
			   String loc) {
	final Department dept = new Department();
	dept.setDeptno(deptno);
	dept.setDname(dname);
	dept.setLocation(loc);
	getEntityManager().persist(dept);
	return dept;
    }

    public List<Employee> findAllEmp()  {
	return getEntityManager().createQuery("select object(o) from Employee o").getResultList();
    }

    public Employee createEmp(Double comm, Long deptno, Long empno, String ename,
			 Timestamp hiredate, String job, Long mgr,
			 Double sal) {
	final Employee emp = new Employee();
	emp.setComm(comm);
	emp.setDeptno(deptno);
	emp.setEmpno(empno);
	emp.setEname(ename);
	emp.setHiredate(hiredate);
	emp.setJob(job);
	emp.setMgr(mgr);
	emp.setSal(sal);
	getEntityManager().persist(emp);
	return emp;
    }

    public void updateEntity(Object entity) {
	getEntityManager().merge( entity );
    }

    public void deleteEntity(Object entity) {
	final EntityManager em = getEntityManager();
	em.remove(em.merge(entity));
    }

    public void refreshEntity(Object entity) {
	getEntityManager().refresh( entity );
    }

    public void shutdown() {
	getEntityManager().close();
    }
    
    public static void main(String[] args) {
       HrmService hrmService = new HrmService();
       
       EntityTransaction tx = hrmService.getEntityManager().getTransaction();
       tx.begin();
       // Create a new customer and persist it.
       hrmService.createDept(new Long(50),"New Dept", "Nieuwegein");
       // Commit the transaction
       tx.commit();

       // run an EJBQL query selecting a Department by some Search Criterium
       String ejbql = "SELECT d FROM Department d WHERE d.location = :location";  // you can tell this is an EJBQL query because of the select d from department d - the whole record is selected, instead of individual columns and it is selected from the Class-name, not the Table-name!
       Query query = hrmService.getEntityManager().createQuery(ejbql);
       query.setParameter("location", "Nieuwegein");
       List<Department> result = query.getResultList();
       // use a little Java 5.0 Autoboxing for simple, elegant for-looping
       for( Department d:result) {
	   System.out.println("Department "+d.getDeptno()+"  "+d.getDname());
       }
       // use the predefined service method for finding all employees
       List<Employee>  emps = hrmService.findAllEmp();
       for (Employee e : emps) { System.out.println(e.getEname()); }
       
       // Close this HrmService instance (and implicitly the EntityManager)
       hrmService.shutdown();
    }
    
}
